==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder extends LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluentImpl<LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder> implements VisitableBuilder<LoadBalancerSettingsConsistentHashLBHttpQueryParameterName,LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder>{
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder() {
    this(false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder(Boolean validationEnabled) {
    this(new LoadBalancerSettingsConsistentHashLBHttpQueryParameterName(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder(LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<?> fluent) {
    this(fluent, false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder(LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LoadBalancerSettingsConsistentHashLBHttpQueryParameterName(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder(LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<?> fluent,LoadBalancerSettingsConsistentHashLBHttpQueryParameterName instance) {
    this(fluent, instance, false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder(LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<?> fluent,LoadBalancerSettingsConsistentHashLBHttpQueryParameterName instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withHttpQueryParameterName(instance.getHttpQueryParameterName());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder(LoadBalancerSettingsConsistentHashLBHttpQueryParameterName instance) {
    this(instance,false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder(LoadBalancerSettingsConsistentHashLBHttpQueryParameterName instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withHttpQueryParameterName(instance.getHttpQueryParameterName());
    }
    this.validationEnabled = validationEnabled; 
  }
  LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<?> fluent;
  Boolean validationEnabled;
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterName build() {
    LoadBalancerSettingsConsistentHashLBHttpQueryParameterName buildable = new LoadBalancerSettingsConsistentHashLBHttpQueryParameterName(fluent.getHttpQueryParameterName());
    return buildable;
  }
  
}

==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder extends LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder> implements VisitableBuilder<LoadBalancerSettingsConsistentHashLBHttpQueryParameterName,LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder>{
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder() {
    this(false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder(Boolean validationEnabled) {
    this(new LoadBalancerSettingsConsistentHashLBHttpQueryParameterName(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder(LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<?> fluent) {
    this(fluent, false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder(LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LoadBalancerSettingsConsistentHashLBHttpQueryParameterName(), validationEnabled);
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder(LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<?> fluent,LoadBalancerSettingsConsistentHashLBHttpQueryParameterName instance) {
    this(fluent, instance, false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder(LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<?> fluent,LoadBalancerSettingsConsistentHashLBHttpQueryParameterName instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLBHttpQueryParameterName());

    if (instance != null) {
      fluent.withHttpQueryParameterName(instance.getHttpQueryParameterName());
      fluent.withHttpQueryParameterName(instance.getHttpQueryParameterName());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder(LoadBalancerSettingsConsistentHashLBHttpQueryParameterName instance) {
    this(instance,false);
  }
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameBuilder(LoadBalancerSettingsConsistentHashLBHttpQueryParameterName instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLBHttpQueryParameterName());

    if (instance != null) {
      this.withHttpQueryParameterName(instance.getHttpQueryParameterName());
      this.withHttpQueryParameterName(instance.getHttpQueryParameterName());
    }
    this.validationEnabled = validationEnabled; 
  }
  LoadBalancerSettingsConsistentHashLBHttpQueryParameterNameFluent<?> fluent;
  Boolean validationEnabled;
  public LoadBalancerSettingsConsistentHashLBHttpQueryParameterName build() {
    LoadBalancerSettingsConsistentHashLBHttpQueryParameterName buildable = new LoadBalancerSettingsConsistentHashLBHttpQueryParameterName(fluent.getHttpQueryParameterName());
    return buildable;
  }
  
}
